@@ -109,7 +109,7 @@ def process_trigger(context, event=None, timeout_secs=1800,
         try:
             webhook = get_secret_by_uri(os.environ.get(fail_alert_webhook_secret_uri))
             try:
-                send_cf_fail_alert(utctime, eventtime, webhook)
+                send_cf_fail_alert(utctime, eventtime, webhook['hook'])
             except Exception as e:
                 logging.error(f'Could not send fail alert to Slack: {type(e).__name__}{e}')
                 pass
